package com.ynet.life.sujrb.file.parser;

import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.format.LifeFormat;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchPaySummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.File;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.Node;
import org.dom4j.io.SAXReader;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchPayXMLFileParser.class */
public class BatchPayXMLFileParser implements BatchFileParserInterface {
    private static final String XPATH_START = "//";
    private static final String XPATH_SEPARATOR = "/";
    private static final String ELEMENT_SUMMARY = "Summary";
    private static final String ELEMENT_TOTAL_NUMBER = "SumRecords";
    private static final String ELEMENT_TOTAL_AMOUNT = "SumMoney";
    private static final String ELEMENT_RECORD_ROOT = "RecordList";
    private static final String ELEMENT_RECORD = "Record";
    private static final String ELEMENT_PAY_ACCOUNT = "payAccount";
    private static final String ELEMENT_PAY_ACCOUNT_NAME = "payAccountName";
    private static final String ELEMENT_REC_ACCOUNT = "recAccount";
    private static final String ELEMENT_REC_ACCOUNT_NAME = "recAccountName";
    private static final String ELEMENT_REC_ACCOUNT_BANK = "recAccountOpenBank";
    private static final String ELEMENT_UNIONBANKNO = "unionBankNo";
    private static final String ELEMENT_TRANCHANNEL = "channel";
    private static final String ELEMENT_CURRENCYTYPE = "currencyType";
    private static final String ELEMENT_TRANSFER_SUM = "payAmount";
    private static final String ELEMENT_TRANSFER_TYPE = "recBankType";
    private static final String ELEMENT_CITY_TYPE = "transferTowardType";
    private static final String ELEMENT_RMTTYPE = "rmtType";
    private static final String ELEMENT_PAY_USE = "payUse";
    private static final String ELEMENT_REM = "payRem";

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        int max;
        BatchPaySummary result = new BatchPaySummary();
        try {
            Element root = new SAXReader().read(new File(filePathName)).getRootElement();
            Node totalNumberNode = root.selectSingleNode("//Summary/SumRecords");
            Node totalAmountNode = root.selectSingleNode("//Summary/SumMoney");
            int recordNumberInput = Integer.parseInt(totalNumberNode.getText());
            BigDecimal totalAmountInput = new BigDecimal(LifeFormat.unFormatCurrency(totalAmountNode.getText()));
            List list = root.selectNodes("//RecordList/Record");
            for (int i = 1; i < list.size(); i++) {
                Node recordNode = (Node) list.get(i);
                result.addRecord(getRecordMap(recordNode));
            }
            if (result.getRecordNumber() != recordNumberInput || totalAmountInput.compareTo(result.getTotalAmount()) != 0) {
                Trace.logWarning("LifeFile", "提交文件中总笔数或总金额和明细不符");
                throw FileConstants.EXCEPTION_VALIDATE_FAIL;
            }
            try {
                max = Integer.parseInt(LifeStandard.getSystemParam("CB_BATCH_TRANSFER_MAX_NUM"));
            } catch (NumberFormatException unused) {
                max = 500;
            }
            if (recordNumberInput > max) {
                Trace.logWarning("LifeAction", "EBCB0505::提交文件总笔数超过要求的值");
                throw new TranFailException("EBCB0505", "提交文件总笔数超过要求的值", false);
            }
            return result;
        } catch (DocumentException ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    private Map getRecordMap(Node recordNode) {
        Map result = new HashMap();
        String xpath = recordNode.getUniquePath();
        String payAccount = recordNode.selectSingleNode(String.valueOf(xpath) + "/payAccount").getText();
        String payAccountName = recordNode.selectSingleNode(String.valueOf(xpath) + "/payAccountName").getText();
        String recAccount = recordNode.selectSingleNode(String.valueOf(xpath) + "/recAccount").getText();
        String recAccountName = recordNode.selectSingleNode(String.valueOf(xpath) + "/recAccountName").getText();
        String recAccountOpenBank = recordNode.selectSingleNode(String.valueOf(xpath) + "/recAccountOpenBank").getText();
        String unionBankNo = recordNode.selectSingleNode(String.valueOf(xpath) + "/unionBankNo").getText();
        String recBankType = recordNode.selectSingleNode(String.valueOf(xpath) + "/recBankType").getText();
        String currencyType = recordNode.selectSingleNode(String.valueOf(xpath) + "/currencyType").getText();
        String payAmount = recordNode.selectSingleNode(String.valueOf(xpath) + "/payAmount").getText();
        String rmtType = recordNode.selectSingleNode(String.valueOf(xpath) + "/rmtType").getText();
        String transferTowardType = recordNode.selectSingleNode(String.valueOf(xpath) + "/transferTowardType").getText();
        String tranChannel = recordNode.selectSingleNode(String.valueOf(xpath) + "/channel").getText();
        String payUse = recordNode.selectSingleNode(String.valueOf(xpath) + "/payUse").getText();
        String payRem = recordNode.selectSingleNode(String.valueOf(xpath) + "/payRem").getText();
        result.put(ELEMENT_PAY_ACCOUNT, payAccount);
        result.put(ELEMENT_PAY_ACCOUNT_NAME, payAccountName);
        result.put(ELEMENT_REC_ACCOUNT, recAccount);
        result.put(ELEMENT_REC_ACCOUNT_NAME, recAccountName);
        result.put(ELEMENT_REC_ACCOUNT_BANK, recAccountOpenBank);
        result.put(ELEMENT_UNIONBANKNO, unionBankNo);
        result.put(ELEMENT_TRANSFER_TYPE, recBankType);
        result.put(ELEMENT_CURRENCYTYPE, currencyType);
        result.put(ELEMENT_TRANSFER_SUM, LifeFormat.unFormatCurrency(LifeFormat.formatCurrency(LifeFormat.unFormatCurrency(payAmount))));
        result.put(ELEMENT_RMTTYPE, rmtType);
        result.put(ELEMENT_CITY_TYPE, transferTowardType);
        result.put("tranChannel", tranChannel);
        result.put(ELEMENT_PAY_USE, payUse);
        result.put(ELEMENT_REM, payRem);
        return result;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
